import os
import zipfile
import requests
import StringIO


class APIBase():
	def __init__(self, home, api_server, debug=False):
		self.home = home
		self.api_server = api_server
		self.debug = debug

	def build_url(self, url):
		return requests.compat.urljoin(self.api_server, url)


class LangAPI(APIBase):
	def list(self):
		langs = requests.get(self.build_url('/api/v1/lang/'))
		langs.raise_for_status()
		return langs.json()


class TaskAPI(APIBase):
	def list(self, lang):
		langs = requests.get(self.build_url('/api/v1/task/'), {'lang': lang})
		langs.raise_for_status()
		return langs.json()

	def get(self, lang, task):
		task = requests.get(self.build_url('/api/v1/task/%s-%s' % (lang, task, )))
		task.raise_for_status()

		task = task.json()
		zip = zipfile.ZipFile(StringIO.StringIO(requests.get(task.get('content'), stream=True).content))

		root = os.path.expanduser(self.home)
		lang_root = os.path.join(root, lang)
		task_root = os.path.join(lang_root, task.get('name'))

		if not os.path.exists(lang_root):
			os.makedirs(lang_root)
			os.makedirs(task_root)

		zip.extractall(task_root)


class OplevelseAPI():
	def __init__(self, *args, **kwargs):
		self.lang = LangAPI(*args, **kwargs)
		self.task = TaskAPI(*args, **kwargs)



import click
from oplevelse import oplevelse


@oplevelse.group()
@click.pass_obj
def task(api):
	"""Task management operations"""


@task.command()
@click.argument('lang')
@click.pass_obj
def list(api, lang):
	"""List tasks for specified lang"""
	for task in api.task.list(lang):
		click.echo(task.get('name'))

@task.command()
@click.argument('lang')
@click.argument('task')
@click.pass_obj
def fetch(api, lang, task):
	"""Fetch specified task"""
	api.task.get(lang, task)


import click
from oplevelse import oplevelse


@oplevelse.group()
@click.pass_obj
def lang(api):
	"""Language management operations"""


@lang.command()
@click.pass_obj
def list(api):
	for lang in api.lang.list():
		click.echo(lang.get('name'))



#!/usr/bin/env python

try:
    from setuptools import setup
except:
    from distutils.core import setup


with open('requirements.txt') as f:
    dependencies = f.read().splitlines()

setup(
        name='oplevelse',
        version='0.0.1',
        description='The Oplevelse CLI',
        url='https://github.com/oplevelse/oplevelse-cli',
        author='Platon Korzh',
        author_email='platon@korzh.io',
        install_requires=dependencies,
        packages=['cli'],
        entry_points={
            'console_scripts': [
                'oplevelse=cli.main:main'
            ]
        }
)



import click

from api import OplevelseAPI

        
@click.group()
@click.option('--oplevelse-home', default='~/oplevelse',
              metavar='HOME', help='Changes the oplevelse home folder location.')
@click.option('--oplevelse-api-server', default='http://127.0.0.1:8000/',
                               metavar='API_URL',
                               help='URL the Oplevelse API server')
@click.option('--debug/--no-debug', default=False)
@click.pass_context
def oplevelse(ctx, oplevelse_home, oplevelse_api_server, debug):
    ctx.obj = OplevelseAPI(oplevelse_home, oplevelse_api_server, debug)